@@ -6,11 +6,12 @@ use warnings;
 
 use base 'WWW::Jawbone::Up::JSON';
 
-__PACKAGE__->add_accessors(qw(distance active_time longest_active longest_idle));
+__PACKAGE__->add_accessors(
+  qw(distance active_time longest_active longest_idle));
 __PACKAGE__->add_accessors({
-  steps       => 'bg_steps',
-  active_burn    => 'calories',
-  resting_burn   => 'bmr_calories',
+  steps        => 'bg_steps',
+  active_burn  => 'calories',
+  resting_burn => 'bmr_calories',
 });
 
 sub total_burn {
